@@ -19,9 +19,9 @@ use overload(
     fallback => 1,
 );
 
-use namespace::sweep;
+use namespace::autoclean;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 # only a few explicitly named attributes.
 # everything else is through AUTOLOAD.
