@@ -3,9 +3,9 @@ use Moose;
 extends 'Dezi::Result';
 use SWISH::3 ':constants';
 use Carp;
-use namespace::sweep;
+use namespace::autoclean;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 has 'relevant_fields' => ( is => 'rw', isa => 'ArrayRef' );
 
