@@ -3,9 +3,9 @@ use Moose;
 use MooseX::StrictConstructor;
 with 'Dezi::Role';
 use Carp;
-use namespace::sweep;
+use namespace::autoclean;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 has 'doc'          => ( is => 'ro', isa => 'Object',  required => 1, );
 has 'score'        => ( is => 'ro', isa => 'Num',     required => 1 );
