@@ -3,9 +3,9 @@ use Moose;
 with 'Dezi::Role';
 use Carp;
 use Types::Standard qw( Int ArrayRef Str Maybe );
-use namespace::sweep;
+use namespace::autoclean;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 has 'start' => (
     is      => 'rw',
