@@ -2,7 +2,7 @@ package Dezi::Test::Result;
 use Moose;
 extends 'Dezi::Result';
 use Carp;
-use namespace::sweep;
+use namespace::autoclean;
 
 __PACKAGE__->meta->make_immutable;
 
